@@ -74,7 +74,7 @@ $(document).ready(function () {
 """ % (self.page_idx, cur_page_elements_js)
         util.create_text_file(file_name_page_js, file_content_page_js)
         # util.display_code(file_name_page_js)
-        print("http://localhost:4507/xxx_dev_blog/%s/%s.png.html" % (cur_pages_dir, self.page_idx))
+        # print("http://localhost:4507/xxx_dev_blog/%s/%s.png.html" % (self.pages_dir, self.page_idx))
 
     def generate_html(self):
         file_name_page_html = "%s.html"%self.cur_img_file()
@@ -98,4 +98,4 @@ $(document).ready(function () {
 """ % (self.page_idx, self.page_idx, self.page_idx)
         util.create_text_file(file_name_page_html, file_content_page_html)
         # util.display_code(file_name_page_html)
-        # print("http://localhost:4507/xxx_dev_blog/%s/%s.png.html" % (cur_pages_dir, self.page_idx))
+        # print("http://localhost:4507/xxx_dev_blog/%s/%s.png.html" % (self.pages_dir, self.page_idx))
